Security Advisories (2)
CPANSA-Jifty-2011-01 (2011-03-17)

The path as passed in the fragment request data structure was used verbatim in the dispatcher and other locations. This possibly allowed requests to walk around ACLs by requesting '/some/safe/place/../../../dangerous' as a fragment.

CPANSA-Jifty-2009-01 (2009-04-09)

The REST plugin would let you call any method on the model.

NAME

Jifty::Plugin::Chart::Renderer::XMLSWF - A chart renderer using XML SWF charts

DESCRIPTION

This chart renderer uses the XML SWF charting tools to render charts.

Plugins:
  - Chart:
      renderer: XMLSWF
      license_key: YOUR_OPTIONAL_LICENSE_KEY

METHODS

init

Save the license key, if any

render

Implemented the "render" in Jifty::Plugin::Chart::Renderer method interface.

SEE ALSO

Jifty::Plugin::Chart, Jifty::Plugin::Chart::Renderer

AUTHOR

Thomas Sibley

COPYRIGHT AND LICENSE

Copyright 2007 Best Practical Solutions, LLC

This is free software and may be modified and distributed under the same terms as Perl itself.